==> egov-common-1.1.6-sources.jar: com/gtis/plat/vo/PfWorkFlowInstanceVo.java <==
package com.gtis.plat.vo;

import java.io.Serializable;
import java.util.Date;

public class PfWorkFlowInstanceVo implements Serializable {

    /**
     *
     */
    private static final long serialVersionUID = -1891407617705773486L;
    String workflowIntanceId;
    String workflowIntanceName;
    Date createTime;
    Date modifyTime;
    String priority;
    String remark;
    int workflowState;
    String proId;
    int handlesDay;
    String timeLimit;
    Date finishTime;    //完成时间
    Date overTime;    //任务截止时间
    String regionCode;
    String workflowDefinitionId;
    String createUser;
    Date modifyDate;
    String monitorId;
    String district;

    public Date getOverTime() {
        return overTime;
    }

    public void setOverTime(Date overTime) {
        this.overTime = overTime;
    }

    public String getMonitorId() {
        return monitorId;
    }

    public void setMonitorId(String monitorId) {
        this.monitorId = monitorId;
    }

    public Date getModifyDate() {
        return modifyDate;
    }

    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }

    public String getCreateUser() {
        return createUser;
    }

    public void setCreateUser(String createUser) {
        this.createUser = createUser;
    }

    public String getWorkflowDefinitionId() {
        return workflowDefinitionId;
    }

    public void setWorkflowDefinitionId(String workflowDefinitionId) {
        this.workflowDefinitionId = workflowDefinitionId;
    }

    public String getWorkflowIntanceId() {
        return workflowIntanceId;
    }

    public void setWorkflowIntanceId(String workflowIntanceId) {
        this.workflowIntanceId = workflowIntanceId;
    }

    public String getWorkflowIntanceName() {
        return workflowIntanceName;
    }

    public void setWorkflowIntanceName(String workflowIntanceName) {
        this.workflowIntanceName = workflowIntanceName;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getModifyTime() {
        return modifyTime;
    }

    public void setModifyTime(Date modifyTime) {
        this.modifyTime = modifyTime;
    }

    public String getPriority() {
        return priority;
    }

    public void setPriority(String priority) {
        this.priority = priority;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public int getWorkflowState() {
        return workflowState;
    }

    public void setWorkflowState(int workflowState) {
        this.workflowState = workflowState;
    }

    public String getProId() {
        return proId;
    }

    public void setProId(String proId) {
        this.proId = proId;
    }

    public int getHandlesDay() {
        return handlesDay;
    }

    public void setHandlesDay(int handlesDay) {
        this.handlesDay = handlesDay;
    }

    public String getTimeLimit() {
        return timeLimit;
    }

    public void setTimeLimit(String timeLimit) {
        this.timeLimit = timeLimit;
    }

    public Date getFinishTime() {
        return finishTime;
    }

    public void setFinishTime(Date finishTime) {
        this.finishTime = finishTime;
    }

    public String getRegionCode() {
        return regionCode;
    }

    public void setRegionCode(String regionCode) {
        this.regionCode = regionCode;
    }

    public String getDistrict() {
        return district;
    }

    public void setDistrict(String district) {
        this.district = district;
    }
}

==> egov-common-1.1.12.4-sources.jar: com/gtis/plat/vo/PfWorkFlowInstanceVo.java <==
package com.gtis.plat.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.HashMap;

public class PfWorkFlowInstanceVo implements Serializable {

    /**
     *
     */
    private static final long serialVersionUID = -1891407617705773486L;
    String workflowIntanceId;
    String workflowIntanceName;
    Date createTime;
    Date modifyTime;
    String priority;
    String remark;
    int workflowState;
    String proId;
    int handlesDay;
    String timeLimit;
    Date finishTime;    //完成时间
    Date overTime;    //任务截止时间
    String regionCode;
    String workflowDefinitionId;
    String createUser;
    Date modifyDate;
    String monitorId;
    String district;

    /**
     * 扩展参数
     * 方便以后平台扩展，不用每次都要修改实体类
     */
    HashMap extensionMap;

    public Date getOverTime() {
        return overTime;
    }

    public void setOverTime(Date overTime) {
        this.overTime = overTime;
    }

    public String getMonitorId() {
        return monitorId;
    }

    public void setMonitorId(String monitorId) {
        this.monitorId = monitorId;
    }

    public Date getModifyDate() {
        return modifyDate;
    }

    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }

    public String getCreateUser() {
        return createUser;
    }

    public void setCreateUser(String createUser) {
        this.createUser = createUser;
    }

    public String getWorkflowDefinitionId() {
        return workflowDefinitionId;
    }

    public void setWorkflowDefinitionId(String workflowDefinitionId) {
        this.workflowDefinitionId = workflowDefinitionId;
    }

    public String getWorkflowIntanceId() {
        return workflowIntanceId;
    }

    public void setWorkflowIntanceId(String workflowIntanceId) {
        this.workflowIntanceId = workflowIntanceId;
    }

    public String getWorkflowIntanceName() {
        return workflowIntanceName;
    }

    public void setWorkflowIntanceName(String workflowIntanceName) {
        this.workflowIntanceName = workflowIntanceName;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getModifyTime() {
        return modifyTime;
    }

    public void setModifyTime(Date modifyTime) {
        this.modifyTime = modifyTime;
    }

    public String getPriority() {
        return priority;
    }

    public void setPriority(String priority) {
        this.priority = priority;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public int getWorkflowState() {
        return workflowState;
    }

    public void setWorkflowState(int workflowState) {
        this.workflowState = workflowState;
    }

    public String getProId() {
        return proId;
    }

    public void setProId(String proId) {
        this.proId = proId;
    }

    public int getHandlesDay() {
        return handlesDay;
    }

    public void setHandlesDay(int handlesDay) {
        this.handlesDay = handlesDay;
    }

    public String getTimeLimit() {
        return timeLimit;
    }

    public void setTimeLimit(String timeLimit) {
        this.timeLimit = timeLimit;
    }

    public Date getFinishTime() {
        return finishTime;
    }

    public void setFinishTime(Date finishTime) {
        this.finishTime = finishTime;
    }

    public String getRegionCode() {
        return regionCode;
    }

    public void setRegionCode(String regionCode) {
        this.regionCode = regionCode;
    }

    public String getDistrict() {
        return district;
    }

    public void setDistrict(String district) {
        this.district = district;
    }

    public HashMap getExtensionMap() {
        return extensionMap;
    }

    public void setExtensionMap(HashMap extensionMap) {
        this.extensionMap = extensionMap;
    }
}
